
import * as echarts from 'echarts';
var data = [];
var dataCount = 10;
var startTime = +new Date();
var categories = ['东1会议室', '东2会议室', '东3会议室'];
var types = [
  { name: '东1会议室', color: '#7b9ce1' },
  { name: '东2会议室', color: '#bd6d6c' },
  { name: '东3会议室', color: '#75d874' },
  { name: '东4会议室', color: '#e0bc78' },
  { name: '东5会议室', color: '#dc77dc' },
  { name: '东6会议室', color: '#72b362' }
];
// Generate mock data
categories.forEach(function (category, index) {
  var baseTime = startTime;
  for (var i = 0; i < dataCount; i++) {
    var typeItem = types[Math.round(Math.random() * (types.length - 1))];
    var duration = Math.round(Math.random() * 1000*60*60*24);
    data.push({
      name: typeItem.name,
      value: [index, baseTime, (baseTime += duration), duration],
      itemStyle: {
        normal: {
          color: typeItem.color
        }
      }
    });
    baseTime += Math.round(Math.random() * 1000*60*60*24);
  }
});
export function renderItem(params, api) {
  var categoryIndex = api.value(0);
  var start = api.coord([api.value(1), categoryIndex]);
  var end = api.coord([api.value(2), categoryIndex]);
  var height = api.size([0, 1])[1] * 0.6;
  var rectShape = echarts.graphic.clipRectByRect(
    {
      x: start[0],
      y: start[1] - height / 2,
      width: end[0] - start[0],
      height: height
    },
    {
      x: params.coordSys.x,
      y: params.coordSys.y,
      width: params.coordSys.width,
      height: params.coordSys.height
    }
  );
  return (
    rectShape && {
      type: 'rect',
      transition: ['shape'],
      shape: rectShape,
      style: api.style()
    }
  );
}

function format(val){
    // return Math.max(0, val - startTime) + ' ms';
    let dt = new Date(val)
    return dt.getFullYear()+'-'+dt.getMonth()+'-'+dt.getDate();
}


export const option = {
  tooltip: {
    formatter: function (params) {
        return `
        ${categories[params.value[0]]}<br>
        会议开始时间：${format(params.value[1])}<br>
        会议结束时间：${format(params.value[2])}<br>
        点击鼠标左键查看详情
        `
      return params.marker + params.name + ': ' + params.value[3] + ' ms';
    }
  },
  title: {
    text: '会议室使用情况总览',
    left: 'center'
  },
  dataZoom: [
    {
      type: 'slider',
      filterMode: 'weakFilter',
      showDataShadow: false,
      top: 400,
      labelFormatter: ''
    },
    {
      type: 'inside',
      filterMode: 'weakFilter'
    }
  ],
  grid: {
    height: 300
  },
  xAxis: {
    min: startTime,
    scale: true,
    axisLabel: {
      formatter: function (val) {
        // return Math.max(0, val - startTime) + ' ms';
        let dt = new Date(val)
        return dt.getFullYear()+'-'+dt.getMonth()+'-'+dt.getDate();
      }
    }
  },
  yAxis: {
    data: categories
  },
  series: [
    {
      type: 'custom',
      renderItem: renderItem,
      itemStyle: {
        opacity: 0.8
      },
      encode: {
        x: [1, 2],
        y: 0
      },
      data: data
    }
  ]
};
